/**
 * Copyright Copyright 2010 Simon Andrews
 *
 *    This file is part of Difference Tracker.
 *
 *    Difference Tracker is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    Difference Tracker is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with Difference Tracker; if not, write to the Free Software
 *    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package uk.ac.bbsrc.babraham.DifferenceTracker.Results;

import java.text.DecimalFormat;

import javax.swing.table.AbstractTableModel;


public class DiffFilterResultsTableModel extends AbstractTableModel {

	private DifferenceResults results;
	private String fileName;
	private DecimalFormat doubleFormat = new DecimalFormat("#.###");
	
	private String [] headers = new String [] {
		"File Name",
		"Static Intensity",
		"Static Intensity per 1000px",
		"Moving Intensity",
		"Moving Intensity per 1000px",
		"Intensity Percentage Moving",
		"Static count",
		"Static count per 1000px",
		"Moving count",
		"Moving count per 1000px",
		"Count Percentage Moving"
	};
	
	public DiffFilterResultsTableModel (String fileName, DifferenceResults results) {
		this.fileName = fileName;
		this.results = results;
	}
	
	
	public int getColumnCount() {
		return 2;
	}

	public int getRowCount() {
		return headers.length;
	}

	public Object getValueAt(int rowIndex, int columnIndex) {
		if (columnIndex == 0) {
			return headers[rowIndex];
		}
		else {
			switch (rowIndex) {
				case 0: return fileName;
				case 1: return doubleFormat.format(results.averageStaticIntensity());
				case 2: return doubleFormat.format(results.averageStaticIntensityPer1000Pixel());
				case 3: return doubleFormat.format(results.averageMovingIntensity());
				case 4: return doubleFormat.format(results.averageMovingIntensityPer1000Pixel());
				case 5: return doubleFormat.format(results.movingIntensityPercentage());
				case 6: return doubleFormat.format(results.averageStaticCount());
				case 7: return doubleFormat.format(results.averageStaticCountPer1000Pixel());
				case 8: return doubleFormat.format(results.averageMovingCount());
				case 9: return doubleFormat.format(results.averageMovingCountPer1000Pixel());
				case 10: return doubleFormat.format(results.movingCountPercentage());
				default: return null;
			}
		}
	}

}
